@@ -78,7 +78,7 @@ def singleton(class_):
 
 
 class Worker:
-    def __init__(self, worker_name, segment_limit=200):
+    def __init__(self, worker_name, create_if_not_exist=True, segment_limit=200):
         self.connection_string = os.environ['AzureWebJobsStorage']
         self.metadata_table_name = worker_name + "Data"
         self.queue_name = worker_name.lower()
@@ -86,15 +86,20 @@ class Worker:
         self.segment_limit = segment_limit
 
         self.table_client = TableService(connection_string=self.connection_string)
-        self.table_client.create_table(self.metadata_table_name)
-        try:
-            self.queue = QueueClient.from_connection_string(conn_str=self.connection_string, queue_name=self.queue_name)
-            self.queue.create_queue()
-        except ResourceExistsError:
-            pass
+        self.queue = QueueClient.from_connection_string(conn_str=self.connection_string, queue_name=self.queue_name)
+
+        if create_if_not_exist:
+            try:
+                self.table_client.create_table(self.metadata_table_name)
+                self.queue.create_queue()
+            except ResourceExistsError:
+                pass
 
         self.pool = ThreadPool(processes=1)
 
+    def exists(self) -> bool:
+        return self.table_client.exists(self.metadata_table_name)
+
     def trigger_blob(self, blob_name, params=None):
         request_id = self._insert_blob_metadata(blob_name, params)
         self._enqueue(request_id)
@@ -177,7 +182,7 @@ class Worker:
                 result, failures, next_chunk = self._process_blob_by_segments(blob_name, func, params)
         except Exception as e:
             if retry_count == 3:
-                self._record_failure(request_id, e)
+                raise e
             else:
                 request_entity['RetryCount'] = retry_count + 1
                 self.table_client.update_entity(self.metadata_table_name, request_entity)
